@@ -19,7 +19,7 @@ from pandas.io import json
 
 from .utility import compress, flatten, merge_tagged_csv, strip_extensions
 
-# pylint: disable=too-many-arguments
+# pylint: disable=too-many-arguments, no-member
 
 
 class ParlaClarinError(ValueError):
@@ -104,6 +104,10 @@ class Utterance:
         self.annotation: Optional[str] = annotation if isinstance(annotation, str) else None
         self.page_number: Optional[str] = page_number
 
+    @property
+    def document_name(self) -> str:
+        return f'{self.who}_{self.u_id}'
+
     @property
     def tagged_text(self) -> str:
         return self.annotation
@@ -266,6 +270,7 @@ class UtteranceMixIn:
 class Speech(UtteranceMixIn):
     """Entity that represents a (processed) speech within a single document."""
 
+    protocol_name: str
     document_name: str
     speech_id: str
     who: str
@@ -321,6 +326,9 @@ class Protocol(UtteranceMixIn):
 
         return self
 
+    def get_year(self) -> int:
+        return int(self.date[:4])
+
     def checksum(self) -> Optional[str]:
         """Compute checksum for entire text."""
         with contextlib.suppress(Exception):
@@ -353,7 +361,7 @@ class Protocol(UtteranceMixIn):
         if segment_level == SegmentLevel.Speech:
             return [
                 dict(
-                    name=self.name,
+                    name=s.document_name,
                     who=s.who,
                     id=s.speech_id,
                     data=s.to_str(content_type),
@@ -365,7 +373,7 @@ class Protocol(UtteranceMixIn):
         if segment_level == SegmentLevel.Who:
             return [
                 dict(
-                    name=self.name,
+                    name=s.document_name,
                     who=s.who,
                     id=s.speech_id,
                     data=s.to_str(content_type),
@@ -378,15 +386,28 @@ class Protocol(UtteranceMixIn):
 
         if segment_level == SegmentLevel.Utterance:
             return [
-                dict(name=self.name, who=u.who, id=u.u_id, data=u.to_str(content_type), page_number=u.page_number)
-                for u in self.utterances
+                dict(
+                    name=f'{self.name}_{i+1:03}',
+                    who=u.who,
+                    id=u.u_id,
+                    data=u.to_str(content_type),
+                    page_number=u.page_number,
+                )
+                for i, u in enumerate(self.utterances)
             ]
 
         if segment_level == SegmentLevel.Paragraph:
             """Only text can be returned for paragraphs"""
+
             return [
-                dict(name=self.name, who=u.who, id=f"{u.u_id}@{i}", data=p, page_number=u.page_number)
-                for u in self.utterances
+                dict(
+                    name=f'{self.name}_{j+1:03}_{i+1:03}',
+                    who=u.who,
+                    id=f"{u.u_id}@{i}",
+                    data=p,
+                    page_number=u.page_number,
+                )
+                for j, u in enumerate(self.utterances)
                 for i, p in enumerate(u.paragraphs)
             ]
 
@@ -412,7 +433,7 @@ class Protocol(UtteranceMixIn):
             Iterable[ProtocolSegment]: [description]
         """
         segments: List[ProtocolSegment] = [
-            ProtocolSegment(content_type=content_type, **d)
+            ProtocolSegment(protocol_name=self.name, content_type=content_type, year=self.get_year(), **d)
             for d in self._to_segments(content_type, segment_level, segment_skip_size)
         ]
 
@@ -429,26 +450,55 @@ class Protocol(UtteranceMixIn):
 @dataclass
 class ProtocolSegment:
 
+    protocol_name: str
     content_type: ContentType
     name: str
     who: str
     id: str
     data: str
     page_number: str
+    year: int
+    n_tokens: int = 0
 
     def __repr__(self) -> str:
         return (
+            f"{self.protocol_name or '*'}\t"
             f"{self.name or '*'}\t"
-            f"{self.id or '?'}\t"
             f"{self.who or '*'}\t"
+            f"{self.id or '?'}\t"
+            f"{self.data or '?'}\t"
             f"{self.page_number or ''}\t"
-            f"{len(self.data)/1024.0:.2f}kB\t"
         )
 
+    #            f"{len(self.data)/1024.0:.2f}kB\t"
+
     def data_z64(self) -> bytes:
         """Compress text, return base64 encoded string."""
         return compress(self.data)
 
+    def to_dict(self):
+        return {
+            'year': self.year,
+            'period': self.year,
+            'who': self.who,
+            'protocol_name': self.protocol_name,
+            'document_name': self.name,
+            'filename': self.filename,
+            'n_tokens': self.n_tokens,
+        }
+
+    @property
+    def extension(self) -> str:
+        return 'txt' if self.content_type == ContentType.Text else 'csv'
+
+    @property
+    def filename(self) -> str:
+        return f'{self.name}.{self.extension}'
+
+    @property
+    def temporal_key(self) -> str:
+        return self.name
+
 
 class ProtocolSegmentIterator(abc.ABC):
     ...
@@ -487,7 +537,7 @@ class ProtocolSegmentIterator(abc.ABC):
         self.speech_merge_strategy: str = speech_merge_strategy  # FIXME: used??
         self.multiproc_processes: int = multiproc_processes or 1
         self.multiproc_chunksize: int = multiproc_chunksize
-        self.multiproc_keep_order: int = multiproc_keep_order
+        self.multiproc_keep_order: bool = multiproc_keep_order
         self.preprocessor: Callable[[str], str] = preprocessor
 
     def __iter__(self):
@@ -538,7 +588,8 @@ class IMergeSpeechStrategy(abc.ABC):
             utterances = protocol.utterances
 
         return Speech(
-            document_name=protocol.name,
+            protocol_name=protocol.name,
+            document_name=f'{protocol.name}_{speech_index:03}',
             speech_id=utterances[0].u_id,
             who=utterances[0].who,
             page_number=utterances[0].page_number,
@@ -599,7 +650,7 @@ class MergeSpeechByChain(IMergeSpeechStrategy):
 
             if next_id is not None:
                 if next_id != u.u_id:
-                    logger.error(
+                    logger.warning(
                         f"{protocol.name}.u[{u.u_id}]: current u.id differs from previous u.next_id '{next_id}'"
                     )
 
